import logging
from argparse import Namespace
from enum import Enum

import toml


class LogLevels(Enum):
    debug = "DEBUG"
    info = "INFO"
    warning = "WARNING"
    error = "ERROR"
    critical = "CRITICAL"


def check(filepath: str) -> None:
    """Check a single file."""

    logging.debug(f"Checking {filepath}...")

    with open(filepath) as f:
        toml.load(f)

    logging.info(f"{filepath}: OK")


def check_multi_thread(*files: str, max_workers: int = 0):
    from concurrent.futures import ThreadPoolExecutor, as_completed

    pool = ThreadPoolExecutor(max_workers=max_workers)
    for task in as_completed([pool.submit(check, x) for x in files]):
        task.result()


def check_single_thread(*files: str):
    list(map(check, files))


def main(args: Namespace) -> int:
    if args.force_single_thread or len(args.files) < 10:
        check_single_thread(*args.files)
    else:
        check_multi_thread(*args.files, max_workers=args.max_workers)
    return 0



import logging
import sys
from argparse import ArgumentParser

from tomlcheck import __description__, __version__
from tomlcheck.main import LogLevels, main


def run() -> None:
    parser = ArgumentParser("tomlcheck", description=__description__)
    parser.add_argument("files", nargs="*")
    parser.add_argument("--version", action="version", version=__version__)
    parser.add_argument(
        "--log-level",
        choices=[x.value for x in LogLevels],
        default=LogLevels.warning.value,
    )
    parser.add_argument("--force-single-thread", action="store_true")
    parser.add_argument("--max-thread-workers", type=int, default=10)

    args = parser.parse_args()

    logging.basicConfig(level=args.log_level)

    sys.exit(main(args=args))


if __name__ == "__main__":
    run()
